Simple Interface - kombu.simple — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Simple Interface - kombu.simple

class `kombu.simple.` `SimpleBase`(channel, producer, consumer, no_ack=False, channel_autoclose=False)
  `clear`()
  `close`()
  `get`(block=True, timeout=None, sync=False)
  `get_nowait`()
  `put`(message, serializer=None, headers=None, compression=None, routing_key=None, **kwargs)
  `qsize`()

class `kombu.simple.` `SimpleBuffer`(channel, name, no_ack=None, queue_opts=None, exchange_opts=None, serializer=None, compression=None, **kwargs)

class `kombu.simple.` `SimpleQueue`(channel, name, no_ack=None, queue_opts=None, exchange_opts=None, serializer=None, compression=None, **kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »